// Include file to read in the configuration file for the online browser
//
// ATTENTION: this file is used from #/bearun/udx/browser_config.aql   AND
//                                   #/bearun/aql/call_help.inc
//
//   Christian Manitz, Poing, 7/97
//      "        "            3/99: *5.7*
//      "        "            5/99: Added docu path to read from anywhere, e.g. CDROM

include #/bearun/msc/mess.lan
include #/aql.aql/includes/func_glob.inc


//============================
function GetBrowserConfig ()
//============================

  return (program.config_dir_user + "/browser.cfg")

end


//=============================
function ReadBrowserConfig ()
//=============================
// Reads in the configuration file for the online browser

// GLOBALS:
//   --
// INPUT:
//   Widget         widget              form to be changed
// RETURN:
//   group with 11 or empty strings     1st: "Help:"    (not in old version)
//                                      2nd: browser tool - HTML or FRAME Viewer
//                                      3rd: browser option - "DEFAULT" | "PATH" | "INST"
//                                      4th: [browser type - "NETSCAPE" | "IEXPLORER" (for Windows only)]
//                                      5th: [installation path of browser program]
//                                      6th: "Docu:"
//                                      7th: browser tool - PDF or FRAME Viewer
//                                      8th: browser option - "DEFAULT" | "PATH" | "INST"
//                                      9th: [installation path of browser program]
//                                     10th: installation path of Online Help           (>= 5.7)
//                                     11th: installation path of Online Documentation  (>= 5.7)
// -----------------------

  OhTool    = ""
  OhOption  = ""
  OhBrowser = ""
  OhProgram = ""
  OhPath    = ""
  OdTool    = ""
  OdOption  = ""
  OdProgram = ""
  OdPath    = ""
  HelpPath  = "#/help/"
  DocuPath  = "#/../../documentation/euklid_design/"
   
  ConfigFile = GetBrowserConfig ()

  if (existf (ConfigFile)) then
    file (ConfigFile) input

    MessIgnore = translate_message (run_war_wrong_browser_config) + "\n" +
                 GetBrowserConfig () + "\n\n" +
                 translate_message (run_war_entries_ignored) + "\n"

    // First part: read configuration of Online Help

    OhTool = parse_line ()
    if (OhTool = "Help:") then
      OhTool = parse_line ()                // use next line = new version
    end
    OhOption = parse_line ()
    if (not valid (OhOption)) then          // file probably empty
      display_error (MessIgnore + "")
      return ( {} )
    end

    switch (OhOption)
      case "DEFAULT": if ((not is_windows_host (program.host))  and  OhTool = "HTML") then
                        display_error (MessIgnore + OhTool)
                        return ( {} )
                      end
      case "PATH"   : OhBrowser = parse_line ()
                      if (is_windows_host (program.host)  and  OhTool = "HTML") then
                        if (len (OhBrowser) = 0  or         // error
                            OhBrowser = "Docu:") then       // error in new version
                          display_error (MessIgnore + OhBrowser)
                          return ( {} )
                        end
                      end
      case "INST"   : OhBrowser = parse_line ()
                      if (is_windows_host (program.host)  and  OhTool = "HTML") then
                        if (len (OhBrowser) = 0  or         // error
                            OhBrowser = "Docu:") then       // error in new version
                          display_error (MessIgnore + OhBrowser)
                          return ( {} )
                        end
                      end
                      OhProgram = parse_line ()
                      if (not valid (OhProgram)  or       // error
                          OhBrowser = "Docu:") then       // error in new version
                        display_error (MessIgnore + OhProgram)
                        return ( {} )
                      end
      otherwise     : display_error (MessIgnore + OhOption)
                      return ( {} )
    end  // switch (OhOption)


    // Second part: read configuration of Online Documentation

    Dummy = parse_line ()                   // Empty
    if (valid (Dummy)) then
      if (len (Dummy) = 0) then
        Dummy = parse_line ()               // Content: "Docu:"
      end
    end
    if (valid (Dummy)) then
      if (Dummy != "Docu:") then
        Dummy = parse_line ()               // probably empty line of Help part
      end
      if (Dummy != "Docu:") then            // old file without docu part
        display_error ("Error reading Documentation part from config file")
        return ( {OhTool, OhOption, OhBrowser, OhProgram, OdTool, OdOption, OdProgram, OhPath, OdPath} )
      end
      OdTool   = parse_line ()
      OdOption = parse_line ()

      switch (OdOption)
        case "DEFAULT": if ((not is_windows_host (program.host))  and  OdTool = "HTML") then
                          display_error (MessIgnore + OdTool)
                          return ( {} )
                        end
        case "PATH"   : OdProgram = ""
        case "INST"   : OdProgram = parse_line ()
                        if (not valid (OdProgram)  or  len (OdProgram) = 0) then
                          display_error (MessIgnore + OdOption)
                          return ( {} )
                        end
        otherwise     : display_error (MessIgnore + OdOption)
      end  // switch (OdOption)

      OhPath = parse_line ()                // installation path of Online Help
      if (valid (OhPath)) then
        if (len (OhPath) = 0) then          // >= 5.7: skip empty line (without browser path)
          OhPath = parse_line ()            // installation path of Online Help
          if (not valid (OhPath)  or  len (OhPath) = 0) then
            OhPath = HelpPath               // no entry in the config
          end
          OdPath = parse_line ()            // installation path of Online Docu
          if (not valid (OdPath)  or  len (OdPath) = 0) then
            OdPath = DocuPath
          end
        else
          OdPath = parse_line ()            // installation path of Online Docu
        end
      else 
        OhPath = HelpPath
        OdPath = DocuPath
      end
    end

    close ()

    return ( {OhTool, OhOption, OhBrowser, OhProgram, OdTool, OdOption, OdProgram, OhPath, OdPath} )
  else
    return ( {} )
  end

end  // ReadBrowserConfig


//---------------------------------
function FileExtendAll (FileName)
//---------------------------------
// Extend filename with all possibilities

// INPUT:
//   FileName       string              Name to extend
//                                      
// RETURN:
//                  string              Extended name

  TmpChar = chr (index (FileName, 1))
  if (TmpChar in {"~", "#", "+"}) then
    ExtendedName = file_extend (FileName)
    if (valid (ExtendedName)) then
      return (ExtendedName)
    else
      return (invalid)
    end
  else
    if (TmpChar = ".") then           // "netscape -remote openFile './xxx'" doesn't work
      PathName = wd ()
      return (PathName + substr (FileName, 2, len (FileName)))
    else    // nothing to do
      return (FileName)
    end
  end
end  // FileExtendAll


