//***********************************************************************<NP>
function RemoveLeadingBlanks ( buffer )
// O------------------------------------------------------------------------O
// | Function   : Fhrende Blanks entfernen                                |
// U------------------------------------------------------------------------U
// EP    : buffer        - Eingabestring
// AP    : Funktionswert - bereinigter Eingabestring
// --------------------------------------------------------------------------
// Author       : P. Artmann (ArP)           Datum : 08.06.1999
// Bearbeiter   :
// akt. Stand   : 11.10.1999
// --------------------------------------------------------------------------
// Beschreibung :  Diese Funktion entfernt fhrende Blanks aus einem
// --------------  Eingabestring.
// --------------------------------------------------------------------------
// nderungen :
// -------------
// 11.10.99   ArP   nicht ber Blankzeilen stolpern
//***************************************************************************
     restlen = len (buffer)
     while (   restlen > 0 and
             ( substr (buffer, 1, 1) = " "  or
               substr (buffer, 1, 1) = "\t"    ) ) do
         if restlen > 1 then
            buffer = substr (buffer, 2, restlen)
         else
            buffer = ""
         end
         restlen = restlen - 1
     end
     return (buffer)
end

//***********************************************************************<NP>
function CheckParamType ( key )
// O------------------------------------------------------------------------O
// | Function   : Konfigurations-Parametertyp auswerten                     |
// U------------------------------------------------------------------------U
// EP    : key           - Parametername eines Konfigurationseintrages
// AP    : Funktionswert - Gruppe
//                         Die Gruppe hat 3 Eintrge
//                         1.) Parametertypnummer
//                             1 : Globaler Datatranslatorparameter
//                             2 : IGES   Parameter
//                             3 : DXF    Parameter
//                             4 : DXFOUT Parameter
//                             5 : DXFIN  Parameter
//                             6 : DWG    Parameter
//                             7 : DWGOUT Parameter
//                             8 : DWGIN  Parameter
//                            99 : unbekannter Parametertyp
//                         2.) Parameterschlssel (Text)
//                         3.) nderungsflag des Parameters
//                             0 : nicht gendert
//                             1 : gendert
//                             2 : neuer Parameter
// --------------------------------------------------------------------------
// Author       : P. Artmann (ArP)           Datum : 08.06.1999
// Bearbeiter   :
// akt. Stand   : 08.06.1999
// --------------------------------------------------------------------------
// Beschreibung :  Diese Funktion setzt die Parametertypen
// --------------  
// --------------------------------------------------------------------------
// nderungen :
// -------------
//***************************************************************************
    ParamChangedFlag = 0     // unchanged
    // now we had to check our Paramtype
    switch key
    case "TRAN"   :          // Global Datatranslator-Switches
         LineType    = 1     // Global Parameter
    case "IGES"   :          // Datatranslator-Switches IGES
         LineType    = 2     // IGES Parameter
    case "DXF"    :          // Datatranslator-Switches DXF
         LineType    = 3     // DXF Parameter
    case "DXFOUT" :          // Datatranslator-Switches DXF
         LineType    = 4     // DXFOUT Parameter
    case "DXFIN"  :          // Datatranslator-Switches DXF
         LineType    = 5     // DXFIN Parameter
    case "DWG"    :          // Datatranslator-Switches DWG
         LineType    = 6     // DWG Parameter
    case "DWGOUT" :          // Datatranslator-Switches DWGOUT
         LineType    = 7     // DWGOUT Parameter
    case "DWGIN"  :          // Datatranslator-Switches DWGIN
         LineType    = 8     // DWGIN Parameter
    otherwise     :
         LineType    = 99    // unknown Parameter
    end
    return ( { LineType, key, ParamChangedFlag } )
end

//***********************************************************************<NP>
function GetParamTypeGroup (paramname)
// O------------------------------------------------------------------------O
// | Function   : Konfigurations-Parametertyp ermitteln                     |
// U------------------------------------------------------------------------U
// EP    : key           - Parametername eines Konfigurationseintrages
// AP    : Funktionswert - Gruppe
//                         Die Gruppe hat 3 Eintrge
//                         1.) Parametertypnummer
//                             1 : Globaler Datatranslatorparameter
//                             2 : IGES   Parameter
//                             3 : DXF    Parameter
//                             4 : DXFOUT Parameter
//                             5 : DXFIN  Parameter
//                             6 : DWG    Parameter
//                             7 : DWGOUT Parameter
//                             8 : DWGIN  Parameter
//                            99 : unbekannter Parametertyp
//                         2.) Parameterschlssel (Text)
//                         3.) nderungsflag des Parameters
//                             0 : nicht gendert
//                             1 : gendert
//                             2 : neuer Parameter
// --------------------------------------------------------------------------
// Author       : P. Artmann (ArP)           Datum : 08.06.1999
// Bearbeiter   :
// akt. Stand   : 11.10.1999
// --------------------------------------------------------------------------
// Beschreibung :  Diese Funktion ermittelt die Parametertypgruppe
// --------------  
// --------------------------------------------------------------------------
// nderungen :
// -------------
// 11.10.99   ArP   unbekannte Zeilen (kein Parameter erkannt) abfangen
//
//***************************************************************************
    // now we had to check our Param
    upos = pos (paramname, "_")
    if upos > 0 then                    // ist es berhaupt ein Parameter
       GlobParam = substr ( paramname, 1, upos-1 )
       ParamTypeGroup = CheckParamType (GlobParam)
    else
       ParamTypeGroup = { 99, "UNKNOWN", 0 }
    end
    return (ParamTypeGroup)
end

function GetParamType ( Param )
    if valid ( Param.el_2 ) then
       if valid ( Param.el_2.el_2 ) then
           return (Param.el_2.el_2)     // Return the Paramtype
       end
    end
    return ("unknown")
end

function GetParamTypeNr ( Param )
    if valid ( Param.el_2 ) then
        if valid ( Param.el_2.el_1 ) then
            return (Param.el_2.el_1)     // Return the Paramtypenumber
        end
    end
    return (99)
end

function GetParamGroup ( ParamLine )
    if valid (ParamLine.el_3) then
        return (ParamLine.el_3)
    end
    return ( {} )
end

function GetCommentLine ( Param )
    if GetParamTypeNr (Param) = 88 then   // valid comment
        return (Param.el_3)
    end
end

function GetNextSeperatorPos ( buffer )
    bpos = 0
    bpos = pos (buffer, " ")
    if bpos = 0 then
        bpos = pos (buffer, "\t")
    end
/*
    if bpos = 0 then
        bpos = pos (buffer, "\r")
    end
*/
    if bpos = 0 then
        bpos = pos (buffer, "\n")
    end
    return (bpos)
end

function GetCommentEndPos ( buffer )
    CEndPos = pos (buffer, "*/")
    return (CEndPos+2)
end

function SplitParam ( buffer )
     ParamLineGroup = { }
     // Add all Entrys to our ParamLineGroup
     restlen = len (buffer)
     while restlen > 0 do
         buffer = RemoveLeadingBlanks ( buffer )
         restlen = len (buffer)
         if restlen > 0 then
             bpos = GetNextSeperatorPos (buffer)
             if bpos = 0 then
                 ParamLineGroup = ParamLineGroup + substr (buffer, 1, restlen)
                 buffer = ""
             else
                 // now we had to check for a comment
                 // "/ *"  is the beginning
                 if substr (buffer, 1, 2) = "/*" then
                     bpos = GetCommentEndPos ( buffer )
                 else
                     if (substr (buffer, 1, 2) = "//" or
                         substr (buffer, 1, 1) = "#"    ) then
                         bpos = restlen + 1
                     end
                 end
                 ParamLineGroup = ParamLineGroup + substr (buffer, 1, bpos-1)
                 if bpos > restlen then
                     buffer = ""
                 else
                     buffer     = substr (buffer, bpos, restlen)
                 end
             end
             restlen        = len (buffer)
         end
     end
     return (ParamLineGroup)
end

function CheckIfParamHasChanged ( ParamLineGroup )
   if valid (ParamLineGroup.el_2) then
      if valid (ParamLineGroup.el_2.el_3) then
         if (ParamLineGroup.el_2.el_3 > 0) then
            return (true)
         end
      end
   end
   return (false)
end

function GetChangedParam (ParamLineGroup)
    ChParam = GetParamGroup (ParamLineGroup)
    Param = ""
    count = 0
    for i in ChParam do
        if ( count > 0 ) then Param = Param + "    " end
        Param = Param + i
        count = count + 1
    end
    return (Param)
end

function GetOriginalParam (ParamLineGroup)
    if valid (ParamLineGroup.el_4) then
        return (ParamLineGroup.el_4)
    else
        return ("# Sorry - something got wrong but there should nothing be wrong, please check the write config AQL")
    end
end

function GetParam (ParamLineGroup)
   ParamHasChanged = CheckIfParamHasChanged (ParamLineGroup)
   if (ParamHasChanged) then
      Param = GetChangedParam (ParamLineGroup)
   else
      Param = GetOriginalParam (ParamLineGroup)
   end
   if substr(Param,1,4) = "DWG_" then
      Param = "TRAN_" + substr(Param,5)
   end
   return (Param)
end


function GetParamsByName (paramname, ParamLineGroup)
    if valid (ParamLineGroup) and len (ParamLineGroup) > 0 then
        ParamLines = ParamLineGroup where not (.el_2.el_1 = 0) and not (.el_2.el_1 = 88) and .el_3.el_1 = paramname
    else
        ParamLines = { }
    end
    return (ParamLines)
end

function GetParamsByNameandValue (paramname, valuegroup, ParamLineGroup)
    if valid (ParamLineGroup) and len (ParamLineGroup) > 0 then
        ParamLines = ParamLineGroup where not (.el_2.el_1 = 0) and not (.el_2.el_1 = 88) and .el_3.el_1 = paramname and .el_3.el_2 = valuegroup.el_1
    else
        ParamLines = { }
    end
    return (ParamLines)
end

function GetParamsByNameandValue2 (paramname, valuegroup, ParamLineGroup)
    if valid (ParamLineGroup) and len (ParamLineGroup) > 0 then
        ParamLines = ParamLineGroup where not (.el_2.el_1 = 0) and not (.el_2.el_1 = 88) and .el_3.el_1 = paramname and .el_3.el_3 = valuegroup.el_2
    else
        ParamLines = { }
    end
    return (ParamLines)
end

function GetParamsByGroup (paramgroupname, ParamLineGroup)
    if valid (ParamLineGroup) and len (ParamLineGroup) > 0 then
        ParamLines = ParamLineGroup where .el_2.el_2 = paramgroupname
    else
        ParamLines = { }
    end
    return (ParamLines)
end

function PrintAllParams ( ParamLineGroup )
    for linegrp in ParamLineGroup do
        [linegrp] nl
    end
end

function ChangeSingleParameter (ParamLine, settinggroup)
    ParamLine.el_2.el_3 = 1   // set the changed flag to changed
    // now change the Paramgroup
    OldLen = len (ParamLine.el_3)
    NewLen = len (settinggroup)
    count = 1
    while count < OldLen and count <= NewLen do
        ParamLine.el_3.["el_" + string (count+1)] = settinggroup.["el_" + string(count)]
        count = count + 1
    end 
    if (NewLen >= OldLen) then
        // there are more Parameters, so we had to add some new one
        while count <= NewLen do
            ParamLine.el_3 = ParamLine.el_3 + settinggroup.["el_" + string(count)]
            count = count + 1
        end
    end
end

function AddNewParameter (paramname, settinggroup, var ParamLineGroup)
    ParamTypeGroup = GetParamTypeGroup (paramname)
    ParamTypeGroup.el_3 = 2   // set the changed flag to param new
    ParamGroup = { paramname }
    for i in settinggroup do
        ParamGroup = ParamGroup + i
    end
    NewParamLine = { 0 }      // means new Line
    NewParamLine = NewParamLine + { ParamTypeGroup } + { ParamGroup } + { "" }
    if valid (ParamLineGroup) then
       ParamLineGroup = ParamLineGroup + { NewParamLine }
    else
       ParamLineGroup = { { NewParamLine } }
    end
    return (ParamLineGroup)
end

function SetParamByName (paramname, settinggroup, var ParamLineGroup)
    ParamLines = GetParamsByName (paramname, ParamLineGroup)
    if len(paramname) > 3 and substr(paramname, 1, 4) = "DWG_" then
        paramname = "TRAN_" + substr(paramname, 5)
    end
    if empty(ParamLines) then  // auch TRAN pruefen
        ParamLines = GetParamsByName (paramname, ParamLineGroup)
    end
    NrFound = len (ParamLines)
    switch NrFound
    case  0   :                  // Param is not in Group -> add it to the group
               ParamLineGroup = AddNewParameter ( paramname, settinggroup, ParamLineGroup )
    case  1   :                  // there is one param to change
               ParamLine = ParamLines.el_1
               ChangeSingleParameter (ParamLine, settinggroup)
    otherwise :                  // there are more then one params with the same name
               //`-> Auswahlkriterium reicht nicht aus,` nl
               //`   da mehrere Parameter mit dem selben Namen vorhanden sind !!` nl
               //`   Jetzt versuchen wir's mit dem 1. Parameterwert` nl
               // now we check the first parameter
               ParamLines = GetParamsByNameandValue (paramname, settinggroup, ParamLines)
               NrFound = len (ParamLines)
               if NrFound = 0 then         // No Param Found, add a new one
                   ParamLineGroup = AddNewParameter ( paramname, settinggroup, ParamLineGroup )
               else
                   if NrFound = 1 then
                       ParamLine = ParamLines.el_1
                       ChangeSingleParameter (ParamLine, settinggroup)
                   else
                       // da sind immer noch mehrere da
                       //`-> Auswahlkriterium reicht immer noch nicht aus,` nl
                       //`   da mehrere Parameter mit dem selben Namen und 1. Parameter vorhanden sind !!` nl
                       //`   Jetzt versuchen wir's auch noch mit dem 2. Parameterwert` nl
                       // now we check the second parameter

                       ParamLines = GetParamsByNameandValue2 (paramname, settinggroup, ParamLines)
                       NrFound = len (ParamLines)
                       if NrFound = 0 then         // No Param Found, add a new one
                           ParamLineGroup = AddNewParameter ( paramname, settinggroup, ParamLineGroup )
                       else
                           if NrFound = 1 then
                               ParamLine = ParamLines.el_1
                               ChangeSingleParameter (ParamLine, settinggroup)
                           else
                               `-> Sorry, there are still ` [NrFound] ` parameters !` nl
                           end
                       end
                   end
               end
    end
    return (ParamLineGroup)
end

function SetParamByNameAndValue2 (paramname, settinggroup, var ParamLineGroup)
    ParamLines = GetParamsByNameandValue2 (paramname, settinggroup, ParamLines)
    NrFound = len (ParamLines)
    if NrFound = 0 then         // No Param Found, add a new one
        ParamLineGroup = AddNewParameter ( paramname, settinggroup, ParamLineGroup )
    else
        if NrFound = 1 then
            ParamLine = ParamLines.el_1
            ChangeSingleParameter (ParamLine, settinggroup)
        else
            `-> Sorry there are still ` [NrFound] ` parameters !` nl
        end
    end
    return (ParamLineGroup)
end

function MergeParamGroups (var OriginalGroup, AddGroup)
    // `-> now merging Param groups` nl
    for Param in AddGroup do
        if Param.el_2.el_3 > 0 then
            // Parameter wurde verndert, Original auch ndern
            settinggroup = { }
            ParLen = len (Param.el_3)
            count = 2
            while count <= ParLen do
                settinggroup = settinggroup + Param.el_3.["el_" + string (count)]
                count = count + 1
            end
            // `changing parameter : ` [Param.el_3.el_1] nl
            // `new value(s)       : ` [settinggroup] nl
            SetParamByName (Param.el_3.el_1, settinggroup, OriginalGroup)
        end
    end
end

function SplitandCheckLine ( number, line )
    ParamTypeGroup = { }
    ChangedFlag    = 0

    if len (line) = 0 then
        LineType    = 0        // This is an Empty line
        LineNumber  = number
        LineContent = "empty"
        Checked = { LineNumber, {LineType, LineContent, 0}, LineContent }
    else
        FirstChar  = substr (line, 1, 1)
        SecondChar = substr (line, 2, 2)
        switch FirstChar
        case "#" :             // This is a comment
                   LineType    = 88
                   LineTypeC   = "comment"
                   LineNumber  = number
                   LineContent = line
        case "/" :
                   if SecondChar = "/" or SecondChar = "*" then
                       LineType    = 88         // Comment
                       LineTypeC   = "comment"
                       LineNumber  = number
                       LineContent = line
                   else
                       LineType    = 9           // unknown
                       LineNumber  = number
                       LineContent = line
                   end
        otherwise :
                   LineType    = 9           // unknown
                   LineNumber  = number
                   LineContent = line
        end

        // Now we know all Comment-Lines, so we had to check
        // our unknown lines

        if LineType = 9 then
            // now we had to check our Params
/*
            upos = pos (line, "_")
            GlobParam = substr ( line, 1, upos-1 )
            ParamTypeGroup = CheckParamType (GlobParam)
*/
            ParamTypeGroup = GetParamTypeGroup (line)

            // now we had to Split the Params into peaces

            ParamLineGroup = SplitParam ( line )

            Checked = { LineNumber, ParamTypeGroup, ParamLineGroup, LineContent }
        else
            Checked = { LineNumber, { LineType, LineTypeC, ChangedFlag }, LineContent }
        end
    end
    return (Checked)
end

function CheckChangedConfig ( ParamGroup )
    SomethingChanged = false
    if valid (level_language) then
       speek = level_language
    else
       speek = program.language
    end
    if not valid (ParamGroup) or len (ParamGroup) = 0 then
        // Konfigurationsdatei nicht gelesen !!
        if speek = deutsch then
           prompt ("Alle Einstellungen sind Default-Einstellungen, das Erzeugen einer Konfig-Datei ist nicht notwendig !")
        else
           prompt ("All settings are default settings, no need to create a config file !")
        end
    else
        // Prfen, ob irgendwas gendert wurde (changed flag)
        for i in ParamGroup do
            if i.el_2.el_3 > 0 then
                SomethingChanged = true
            end
        end
        if SomethingChanged then
            // Hier muss jetzt wieder die Konfigurationsdatei geschrieben werden
            if speek = deutsch then
                prompt ("Sie haben Konfigurationsparameter verndert, diese werden in der Konfigurationsdatei gespeichert !")
            else
                prompt ("You had changed configuration settings, i will rewrite your config file !")
            end
        else
            // Es wurde nichts gendert !!
            if speek = deutsch then
               prompt ("Die Konfigurationsparameter wurden nicht verndert, ein Abspeichern ist nicht notwendig !")
            else
               prompt ("Nothing changed, no need to rewrite your config file")
            end
        end
    end
    return (SomethingChanged)
end

function ReadConfigFile ( filename )

    file filename input

    // Read and check all Lines in this file
    // Set Linetypes and Line-numbers to rewrite file
    // with all comments, unused switches, ...
    //
    nr   = 1
    ParamLineGroup = {}
    line = ""
    while valid(line) do 
      line = parse_line ()
      if valid (line) then
          LineGrp = SplitandCheckLine (nr, line)
          nr = nr + 1
          ParamLineGroup = ParamLineGroup + { LineGrp }
      end
    end
    close()
    file <screen> input

    return (ParamLineGroup)
end

function CreateDefaultDWGConfig ( filename )

  ok = file_access (filename, "w")

  if (ok) then

    file filename output

    `# Default Configfile created by Datatranslators Config Editor at ` [date()] nl
    `# -----------------------------------------------------------`nl
    `#` nl
    `# uncomment DWGOUT_graphAttrMode  useObjectDSettings if you want to transfer original ObjectD Layernames to DWG/DXF` nl
    `# uncomment DWGOUT_graphAttrMode  useLineStyleAssign if you want to use only Linestyles (not from Layer) - see DWG_LineStyleAssign` nl
    `# (Don't forget to remove or comment the other lines DWGOUT_graphAttrMode)` nl
    `#` nl
    `#DWGOUT_graphAttrMode   useObjectDSettings` nl
    `#DWGOUT_graphAttrMode   useLineStyleAssign` nl
    `DWGOUT_graphAttrMode	useLineStyleLayer` nl
    `#                                                  OD      ACAD` nl
    `# --------------------- ACAD-Layername ----------  Style - Color -- Comment` nl
    `#` nl
    `DWGOUT_layerDefine      ObjectD_Text               1       4       /* magenta      */` nl
    `DWGOUT_layerDefine      ObjectD_Measure            1       5       /* blau         */` nl
    `DWGOUT_layerDefine      ObjectD_Hatch              1       6       /* violett      */` nl
    `DWGOUT_layerDefine      ObjectD_FilledHatch        1     132       /* blauton      */` nl
    `DWGOUT_layerDefine      ObjectD_FilledHiddenHatch  1     250       /* schwarz      */` nl
    `#` nl
    `DWGOUT_layerDefine      ObjectD_Thin               1       1       /* rot          */` nl
    `DWGOUT_layerDefine      ObjectD_Medium             1       2       /* gelb         */` nl
    `DWGOUT_layerDefine      ObjectD_Thick              1       7       /* weiss        */` nl
    `DWGOUT_layerDefine      ObjectD_Thin_Dashed        2       1       /* rot          */` nl
    `DWGOUT_layerDefine      ObjectD_Medium_Dashed      2       2       /* gelb         */` nl
    `DWGOUT_layerDefine      ObjectD_Thick_Dashed       2       7       /* weiss        */` nl
    `DWGOUT_layerDefine      ObjectD_Thin_DashDotted    3       1       /* rot          */` nl
    `DWGOUT_layerDefine      ObjectD_Medium_DashDotted  3       2       /* gelb         */` nl
    `DWGOUT_layerDefine      ObjectD_Thick_DashDotted   3       7       /* weiss        */` nl
    `DWGOUT_layerDefine      ObjectD_Thin_DashDotDot    4       1       /* rot          */` nl
    `DWGOUT_layerDefine      ObjectD_Medium_DashDotDot  4       2       /* gelb         */` nl
    `DWGOUT_layerDefine      ObjectD_Thick_DashDotDot   4       7       /* weiss        */` nl
    `DWGOUT_layerDefine      ObjectD_Thin_DashDot       5       1       /* rot          */` nl
    `DWGOUT_layerDefine      ObjectD_Medium_DashDot     5       2       /* gelb         */` nl
    `DWGOUT_layerDefine      ObjectD_Thick_DashDot      5       7       /* weiss        */` nl
    `DWGOUT_layerDefine      ObjectD_Thin_ZickZack      6       1       /* rot          */` nl
    `DWGOUT_layerDefine      ObjectD_Medium_ZickZack    6       2       /* gelb         */` nl
    `DWGOUT_layerDefine      ObjectD_Thick_ZickZack     6       7       /* weiss        */` nl
    `#` nl
    `# in the following section we define the intervall of line thickness within ObjectD` nl
    `# which will be used to transfer ObjectD elements to the appropriate layer of DWG/DXF` nl
    `#` nl
    `#                      OD       ` nl
    `# -------------------- Style -- min --- max --- move to layer` nl
    `#` nl
    `DWGOUT_lineStyleLayer   1       min     0.26    ObjectD_Thin` nl
    `DWGOUT_lineStyleLayer   1       0.26    0.36    ObjectD_Medium` nl
    `DWGOUT_lineStyleLayer   1       0.36    max     ObjectD_Thick` nl
    `DWGOUT_lineStyleLayer   2       min     0.26    ObjectD_Thin_Dashed` nl
    `DWGOUT_lineStyleLayer   2       0.26    0.36    ObjectD_Medium_Dashed` nl
    `DWGOUT_lineStyleLayer   2       0.36    max     ObjectD_Thick_Dashed` nl
    `DWGOUT_lineStyleLayer   3       min     0.26    ObjectD_Thin_DashDotted` nl
    `DWGOUT_lineStyleLayer   3       0.26    0.36    ObjectD_Medium_DashDotted` nl
    `DWGOUT_lineStyleLayer   3       0.36    max     ObjectD_Thick_DashDotted` nl
    `DWGOUT_lineStyleLayer   4       min     0.26    ObjectD_Thin_DashDotDot` nl
    `DWGOUT_lineStyleLayer   4       0.26    0.36    ObjectD_Medium_DashDotDot` nl
    `DWGOUT_lineStyleLayer   4       0.36    max     ObjectD_Thick_DashDotDot` nl
    `DWGOUT_lineStyleLayer   5       min     0.26    ObjectD_Thin_DashDot` nl
    `DWGOUT_lineStyleLayer   5       0.26    0.36    ObjectD_Medium_DashDot` nl
    `DWGOUT_lineStyleLayer   5       0.36    max     ObjectD_Thick_DashDot` nl
    `DWGOUT_lineStyleLayer   6       min     0.26    ObjectD_Thin_ZickZack` nl
    `DWGOUT_lineStyleLayer   6       0.26    0.36    ObjectD_Medium_ZickZack` nl
    `DWGOUT_lineStyleLayer   6       0.36    max     ObjectD_Thick_ZickZack` nl
    `#` nl
    `DWGOUT_lineStyleLayer   text              ObjectD_Text` nl
    `DWGOUT_lineStyleLayer   measure           ObjectD_Measure` nl
    `DWGOUT_lineStyleLayer   hatch             ObjectD_Hatch` nl
    `DWGOUT_lineStyleLayer   filledhatch       ObjectD_FilledHatch` nl
    `DWGOUT_lineStyleLayer   filledhiddenhatch ObjectD_FilledHiddenHatch` nl
    `#` nl
    `# The following lines are used if you set DWGOUT_graphAttrMode to useLineStyleAssign` nl
    `#` nl
    `DWGOUT_lineStyleAssign 1 SOLID      "____________________________" 2 "10.0,10.0"` nl
    `DWGOUT_lineStyleAssign 2 DASHED     "__ __ __ __ __ __ __ __ __ _" 2 "12.0,-3"` nl
    `DWGOUT_lineStyleAssign 3 DASHDOTTED "_____ . _____ . _____ . ____" 4 "12.0,-3,0.5,-3"` nl
    `DWGOUT_lineStyleAssign 4 DASHDOTDOT "_____ . . _____ . . _____ . " 6 "12.0,-3,0.5,-3,0.5,-3"` nl
    `DWGOUT_lineStyleAssign 5 DOTTED     "............................" 2 "0.5, -3"` nl
    `DWGOUT_lineStyleAssign 6 DASHDOT    "___ . ___ . ___ . ___ . ___ " 4 "6.0,-2,0.5,-2"` nl
    `DWGOUT_lineStyleAssign 7 DASHDOT    "___ . ___ . ___ . ___ . ___ " 4 "6.0,-2,0.5,-2"` nl
    `#` nl
    `# The following lines are used for reading dwg-files` nl
    `#` nl
    `DWGIN_lineStyleAssign 1 SOLID` nl
    `DWGIN_lineStyleAssign 1 AUSGEZOGEN` nl
    `DWGIN_lineStyleAssign 1 CONTINUOUS` nl
    `DWGIN_lineStyleAssign 1 10                /* Medusa PEN 10                        */` nl
    `DWGIN_lineStyleAssign 2 DASHED` nl
    `DWGIN_lineStyleAssign 2 DASHED2           /* dashed lines from ouptput_dxf (V12)  */` nl
    `DWGIN_lineStyleAssign 2 VERDECKT2         /* dashed lines from ouptput_dxf (V12)  */` nl
    `DWGIN_lineStyleAssign 2 Acad_iso02w100    /* ISO-Strichlinie                      */` nl
    `DWGIN_lineStyleAssign 2 Gen3` nl
    `DWGIN_lineStyleAssign 2 Gen3a` nl
    `DWGIN_lineStyleAssign 2 HIDDENX2` nl
    `DWGIN_lineStyleAssign 3 DASHDOTTED` nl
    `DWGIN_lineStyleAssign 3 CENTER` nl
    `DWGIN_lineStyleAssign 3 CENTER2           /* center lines from ouptput_dxf (V12)  */` nl
    `DWGIN_lineStyleAssign 3 MITTE2            /* center lines from ouptput_dxf (V12)  */` nl
    `DWGIN_lineStyleAssign 3 CENTERX2` nl
    `DWGIN_lineStyleAssign 3 HIDDEN` nl
    `DWGIN_lineStyleAssign 3 Acad_iso04w100    /* ISO Lang gestrichelt punktiert       */` nl
    `DWGIN_lineStyleAssign 3 Gen7` nl
    `DWGIN_lineStyleAssign 3 Gen7a` nl
    `DWGIN_lineStyleAssign 4 DASHDOTDOT` nl
    `DWGIN_lineStyleAssign 4 DIVIDE` nl
    `DWGIN_lineStyleAssign 4 DIVIDE2           /* broken lines from ouptput_dxf (V12)  */` nl
    `DWGIN_lineStyleAssign 4 GETRENNT2         /* broken lines from ouptput_dxf (V12)  */` nl
    `DWGIN_lineStyleAssign 4 Acad_iso05w100    /* ISO Lang gestrichelt doppelpunktiert */` nl
    `DWGIN_lineStyleAssign 4 PHANTOM` nl
    `DWGIN_lineStyleAssign 4 PHANTOM2          /* phantom lines from ouptput_dxf (V12) */` nl
    `DWGIN_lineStyleAssign 4 PHANTOMX2` nl
    `DWGIN_lineStyleAssign 5 DOT` nl
    `DWGIN_lineStyleAssign 5 DOT2              /* dotted lines from ouptput_dxf (V12)  */` nl
    `DWGIN_lineStyleAssign 5 PUNKT2            /* dotted lines from ouptput_dxf (V12)  */` nl
    `DWGIN_lineStyleAssign 5 DASHDOT` nl
    `DWGIN_lineStyleAssign 5 Acad_iso07w100    /* ISO punktiert */` nl
    `DWGIN_lineStyleAssign 5 HIDDEN2` nl
    `#` nl
    `# now here is your Color-Assignment in the notation OD - ACAD` nl
    `# NOTE that this assignment is only valid if you had changed the color of element(s) within ObjectD` nl
    `#` nl
    `DWG_colorAssign  1   5    /* RGB :   0   0 255 : blau     */` nl
    `DWG_colorAssign  2  16    /* RGB : 165  42  42            */` nl
    `DWG_colorAssign  3   2    /* RGB : 255 255   0 : gelb     */` nl
    `DWG_colorAssign  4   7    /* RGB : 255 255 255 : weiss    */` nl
    `DWG_colorAssign  5   1    /* RGB : 255   0   0 : rot      */` nl
    `DWG_colorAssign  6 250    /* RGB :   0   0   0 : schwarz  */` nl
    `DWG_colorAssign  7   9    /* RGB : 207 202 201 : grau     */` nl
    `DWG_colorAssign  8  18    /* RGB :  91  11   0 */` nl
    `DWG_colorAssign  9 137    /* RGB : 105 185 180 */` nl
    `DWG_colorAssign 10  16    /* RGB : 139   0   0 */` nl
    `DWG_colorAssign 11 183    /* RGB : 203 197 255 */` nl
    `DWG_colorAssign 12  14    /* RGB : 180  50  50 : orange   */` nl
    `DWG_colorAssign 13 185    /* RGB : 191 166 252 */` nl
    `DWG_colorAssign 14 175    /* RGB :   0   0 128 */` nl
    `DWG_colorAssign 15 255    /* RGB : 255 255 255 : weiss    */` nl
    `DWG_colorAssign 16   4    /* RGB :  49 250 250 : cyan     */` nl
    `DWG_colorAssign 17 123    /* RGB :  17 255 200 */` nl
    `DWG_colorAssign 18 113    /* RGB : 100 250 155 */` nl
    `DWG_colorAssign 19 103    /* RGB : 155 255 150 */` nl
    `DWG_colorAssign 20  93    /* RGB : 150 224 109 */` nl
    `DWG_colorAssign 21  83    /* RGB :  99 200  99 */` nl
    `DWG_colorAssign 22  73    /* RGB :  49 165  80 */` nl
    `DWG_colorAssign 23  75    /* RGB :  25 175   0 */` nl
    `DWG_colorAssign 24  85    /* RGB :   0 125   0 */` nl
    `DWG_colorAssign 25  87    /* RGB :   0 110  25 */` nl
    `DWG_colorAssign 26  89    /* RGB :  25  90   5 */` nl
    `DWG_colorAssign 27  99    /* RGB :   0  75  25 */` nl
    `DWG_colorAssign 28 139    /* RGB :  80  85  75 */` nl
    `DWG_colorAssign 29 149    /* RGB :  95  75  75 */` nl
    `DWG_colorAssign 30  27    /* RGB : 125  90  46 */` nl
    `DWG_colorAssign 31  37    /* RGB : 156 110  46 */` nl
    `DWG_colorAssign 32   5    /* RGB :   0   0 255 : blau     */` nl
    `DWG_colorAssign 33 184    /* RGB : 100  10 251 */` nl
    `DWG_colorAssign 34 206    /* RGB : 150  15 251 */` nl
    `DWG_colorAssign 35 204    /* RGB : 175   0 251 */` nl
    `DWG_colorAssign 36 202    /* RGB : 200  10 251 */` nl
    `DWG_colorAssign 37 212    /* RGB : 236   0 246 */` nl
    `DWG_colorAssign 38 211    /* RGB : 252 115 252 */` nl
    `DWG_colorAssign 39 241    /* RGB : 250 175 230 */` nl
    `DWG_colorAssign 40 231    /* RGB : 230 180 225 */` nl
    `DWG_colorAssign 41 221    /* RGB : 240 210 215 */` nl
    `DWG_colorAssign 42 211    /* RGB : 249 220 229 */` nl
    `DWG_colorAssign 43  43    /* RGB : 245 210 190 */` nl
    `DWG_colorAssign 44  33    /* RGB : 249 200 150 */` nl
    `DWG_colorAssign 45  23    /* RGB : 240 190 110 */` nl
    `DWG_colorAssign 46  35    /* RGB : 220 175 125 */` nl
    `DWG_colorAssign 47  45    /* RGB : 190 150 100 */` nl
    `DWG_colorAssign 48  24    /* RGB : 150   0   0 */` nl
    `DWG_colorAssign 49  14    /* RGB : 200   0   0 */` nl
    `DWG_colorAssign 50  12    /* RGB : 235  50   0 */` nl
    `DWG_colorAssign 51  22    /* RGB : 250  75   0 */` nl
    `DWG_colorAssign 52  32    /* RGB : 255 115  30 */` nl
    `DWG_colorAssign 53  42    /* RGB : 250 140   0 */` nl
    `DWG_colorAssign 54  40    /* RGB : 246 180   0 */` nl
    `DWG_colorAssign 55  41    /* RGB : 251 220   0 */` nl
    `DWG_colorAssign 56  51    /* RGB : 251 251   0 */` nl
    `DWG_colorAssign 57  61    /* RGB : 221 251   0 */` nl
    `DWG_colorAssign 58  71    /* RGB : 176 250   0 */` nl
    `DWG_colorAssign 59   3    /* RGB :  70 255   0 : grn */` nl
    `DWG_colorAssign 60  81    /* RGB :   1 251  90 */` nl
    `DWG_colorAssign 61 101    /* RGB :   0 251 126 */` nl
    `DWG_colorAssign 62 111    /* RGB :   0 251 161 */` nl
    `DWG_colorAssign 63 121    /* RGB :   0 251 196 */` nl
    `#` nl
    `# now here is your Color-Assignment in the notation Datatranslator - ACAD` nl
    `# used to translate Autocad-Colors (DWGIN)` nl
    `#` nl
    `DWGIN_colorAssign  5   1    /* RGB : 255   0   0 : rot        */` nl
    `DWGIN_colorAssign  3   2    /* RGB : 255 255   0 : gelb       */` nl
    `DWGIN_colorAssign 59   3    /* RGB :  70 255   0 : gruen      */` nl
    `DWGIN_colorAssign 16   4    /* RGB :  49 250 250 : cyan       */` nl
    `DWGIN_colorAssign  1   5    /* RGB :   0   0 255 : blau       */` nl
    `DWGIN_colorAssign 38   6    /* RGB : 255   0 255 : magenta    */` nl
    `DWGIN_colorAssign  4   7    /* RGB : 255 255 255 : weiss      */` nl
    `DWGIN_colorAssign 28   8    /* RGB :   ?   ?   ? : dunkelgrau */` nl
    `DWGIN_colorAssign  7   9    /* RGB : 207 202 201 : grau       */` nl
    `DWGIN_colorAssign 50  10    /* RGB :   ?   ?   ? : rot        */` nl
    `DWGIN_colorAssign 41  11    /* RGB :   ?   ?   ? : rotton     */` nl
    `DWGIN_colorAssign 50  12    /* RGB : 235  50   0 : ?          */` nl
    `DWGIN_colorAssign 43  13    /* RGB :   ?   ?   ? : ?          */` nl
    `DWGIN_colorAssign 48  14    /* RGB : 200   0   0 : rotton     */` nl
    `DWGIN_colorAssign 48  15    /* RGB :   ?   ?   ? : ?          */` nl
    `DWGIN_colorAssign  2  16    /* RGB : 165  42  42 : ?          */` nl
    `DWGIN_colorAssign 48  17    /* RGB :   ?   ?   ? : rotton     */` nl
    `DWGIN_colorAssign  8  18    /* RGB :  91  11   0 : ?          */` nl
    `DWGIN_colorAssign 29  19    /* RGB :   ?   ?   ? : dunkelgrau */` nl
    `DWGIN_colorAssign 49  20    /* RGB :   ?   ?   ? : ?          */` nl
    `DWGIN_colorAssign 43  21    /* RGB :   ?   ?   ? : rotton     */` nl
    `DWGIN_colorAssign 51  22    /* RGB : 250  75   0 : ?          */` nl
    `DWGIN_colorAssign 45  23    /* RGB : 240 190 110 : ?          */` nl
    `DWGIN_colorAssign 48  24    /* RGB : 150   0   0 : ?          */` nl
    `DWGIN_colorAssign 30  25    /* RGB :   ?   ?   ? : ?          */` nl
    `DWGIN_colorAssign 30  26    /* RGB :   ?   ?   ? : ?          */` nl
    `DWGIN_colorAssign 30  27    /* RGB : 125  90  46 : ?          */` nl
    `DWGIN_colorAssign  8  28    /* RGB :   ?   ?   ? : dunkelgrau */` nl
    `DWGIN_colorAssign  8  29    /* RGB :   ?   ?   ? : dunkelgrau */` nl
    `DWGIN_colorAssign 53  30    /* RGB :   ?   ?   ? : orange     */` nl
    `DWGIN_colorAssign 44  31    /* RGB :   ?   ?   ? : rotton     */` nl
    `DWGIN_colorAssign 52  32    /* RGB : 255 115  30 : ?          */` nl
    `DWGIN_colorAssign 44  33    /* RGB : 249 200 150 : ?          */` nl
    `DWGIN_colorAssign 31  34    /* RGB :   ?   ?   ? : ?          */` nl
    `DWGIN_colorAssign 46  35    /* RGB : 220 175 125 : ?          */` nl
    `DWGIN_colorAssign 30  36    /* RGB :   ?   ?   ? : ?          */` nl
    `DWGIN_colorAssign 31  37    /* RGB : 156 110  46 : ?          */` nl
    `DWGIN_colorAssign  8  38    /* RGB :   ?   ?   ? : dunkelgrau */` nl
    `DWGIN_colorAssign  8  39    /* RGB :   ?   ?   ? : dunkelgrau */` nl
    `DWGIN_colorAssign 54  40    /* RGB : 246 180   0 : ?          */` nl
    `DWGIN_colorAssign 55  41    /* RGB : 251 220   0 : ?          */` nl
    `DWGIN_colorAssign 53  42    /* RGB : 250 140   0 : ?          */` nl
    `DWGIN_colorAssign 43  43    /* RGB : 245 210 190 : ?          */` nl
    `DWGIN_colorAssign 47  44    /* RGB :   ?   ?   ? : ?          */` nl
    `DWGIN_colorAssign 47  45    /* RGB : 190 150 100 : ?          */` nl
    `DWGIN_colorAssign 47  46    /* RGB :   ?   ?   ? : ?          */` nl
    `DWGIN_colorAssign 47  47    /* RGB :   ?   ?   ? : ?          */` nl
    `DWGIN_colorAssign  8  48    /* RGB :   ?   ?   ? : dunkelgrau */` nl
    `DWGIN_colorAssign  8  49    /* RGB :   ?   ?   ? : dunkelgrau */` nl
    `DWGIN_colorAssign 56  50    /* RGB :   ?   ?   ? : gelbton    */` nl
    `DWGIN_colorAssign 56  51    /* RGB : 251 251   0 : gelbton    */` nl
    `DWGIN_colorAssign 57  52    /* RGB :   ?   ?   ? : gelbton    */` nl
    `DWGIN_colorAssign 57  53    /* RGB :   ?   ?   ? : gelbton    */` nl
    `DWGIN_colorAssign 57  54    /* RGB :   ?   ?   ? : gelbton    */` nl
    `DWGIN_colorAssign 57  55    /* RGB :   ?   ?   ? : gelbton    */` nl
    `DWGIN_colorAssign 26  56    /* RGB :   ?   ?   ? : ?          */` nl
    `DWGIN_colorAssign 27  57    /* RGB :   ?   ?   ? : ?          */` nl
    `DWGIN_colorAssign  8  58    /* RGB :   ?   ?   ? : dunkelgrau */` nl
    `DWGIN_colorAssign  8  59    /* RGB :   ?   ?   ? : dunkelgrau */` nl
    `DWGIN_colorAssign 58  60    /* RGB :   ?   ?   ? : gelbgruen  */` nl
    `DWGIN_colorAssign 57  61    /* RGB : 221 251   0 : gelbgruen  */` nl
    `DWGIN_colorAssign 20  62    /* RGB :   ?   ?   ? : gelbgruen  */` nl
    `DWGIN_colorAssign 21  63    /* RGB :   ?   ?   ? : gelbgruen  */` nl
    `DWGIN_colorAssign 22  64    /* RGB :   ?   ?   ? : gruenton   */` nl
    `DWGIN_colorAssign 23  65    /* RGB :   ?   ?   ? : gruenton   */` nl
    `DWGIN_colorAssign 24  66    /* RGB :   ?   ?   ? : gruenton   */` nl
    `DWGIN_colorAssign 25  67    /* RGB :   ?   ?   ? : gruenton   */` nl
    `DWGIN_colorAssign 26  68    /* RGB :   ?   ?   ? : graugruen  */` nl
    `DWGIN_colorAssign 27  69    /* RGB :   ?   ?   ? : graugruen  */` nl
    `DWGIN_colorAssign 59  70    /* RGB :   ?   ?   ? : gruenton   */` nl
    `DWGIN_colorAssign 58  71    /* RGB : 176 250   0 : gelbgruen  */` nl
    `DWGIN_colorAssign 23  72    /* RGB :   ?   ?   ? : gruenton   */` nl
    `DWGIN_colorAssign 22  73    /* RGB :  49 165  80 : gruenton   */` nl
    `DWGIN_colorAssign 24  74    /* RGB :   ?   ?   ? : gruenton   */` nl
    `DWGIN_colorAssign 23  75    /* RGB :  25 175   0 : ?          */` nl
    `DWGIN_colorAssign 25  76    /* RGB :   ?   ?   ? : graugruen  */` nl
    `DWGIN_colorAssign 26  77    /* RGB :   ?   ?   ? : graugruen  */` nl
    `DWGIN_colorAssign 26  78    /* RGB :   ?   ?   ? : graugruen  */` nl
    `DWGIN_colorAssign 27  79    /* RGB :   ?   ?   ? : graugruen  */` nl
    `DWGIN_colorAssign 59  80    /* RGB :   ?   ?   ? : gruenton   */` nl
    `DWGIN_colorAssign 60  81    /* RGB :   1 251  90 : ?          */` nl
    `DWGIN_colorAssign 24  82    /* RGB :   ?   ?   ? : gruenton   */` nl
    `DWGIN_colorAssign 21  83    /* RGB :  99 200  99 : ?          */` nl
    `DWGIN_colorAssign 25  84    /* RGB :   ?   ?   ? : gruenton   */` nl
    `DWGIN_colorAssign 24  85    /* RGB :   0 125   0 : gruenton   */` nl
    `DWGIN_colorAssign 24  86    /* RGB :   ?   ?   ? : gruenton   */` nl
    `DWGIN_colorAssign 25  87    /* RGB :   0 110  25 : gruenton   */` nl
    `DWGIN_colorAssign 27  88    /* RGB :   ?   ?   ? : graugruen  */` nl
    `DWGIN_colorAssign 26  89    /* RGB :  25  90   5 : graugruen  */` nl
    `DWGIN_colorAssign 60  90    /* RGB :   ?   ?   ? : tuerkis    */` nl
    `DWGIN_colorAssign 61  91    /* RGB :   ?   ?   ? : tuerkis    */` nl
    `DWGIN_colorAssign 21  92    /* RGB :   ?   ?   ? : gruenton   */` nl
    `DWGIN_colorAssign 20  93    /* RGB : 150 224 109 : gruenton   */` nl
    `DWGIN_colorAssign 24  94    /* RGB :   ?   ?   ? : gruenton   */` nl
    `DWGIN_colorAssign 25  95    /* RGB :   ?   ?   ? : gruenton   */` nl
    `DWGIN_colorAssign 24  96    /* RGB :   ?   ?   ? : gruenton   */` nl
    `DWGIN_colorAssign 25  97    /* RGB :   ?   ?   ? : gruenton   */` nl
    `DWGIN_colorAssign 26  98    /* RGB :   ?   ?   ? : graugruen  */` nl
    `DWGIN_colorAssign 27  99    /* RGB :   0  75  25 : graugruen  */` nl
    `DWGIN_colorAssign 59 100    /* RGB :   ?   ?   ? : tuerkis    */` nl
    `DWGIN_colorAssign 61 101    /* RGB :   0 251 126 : gruenton   */` nl
    `DWGIN_colorAssign 20 102    /* RGB :   ?   ?   ? : gruenton   */` nl
    `DWGIN_colorAssign 19 103    /* RGB : 155 255 150 : gruenton   */` nl
    `DWGIN_colorAssign 24 104    /* RGB :   ?   ?   ? : gruenton   */` nl
    `DWGIN_colorAssign 25 105    /* RGB :   ?   ?   ? : gruenton   */` nl
    `DWGIN_colorAssign 24 106    /* RGB :   ?   ?   ? : gruenton   */` nl
    `DWGIN_colorAssign 25 107    /* RGB :   ?   ?   ? : gruenton   */` nl
    `DWGIN_colorAssign 26 108    /* RGB :   ?   ?   ? : graugruen  */` nl
    `DWGIN_colorAssign 27 109    /* RGB :   ?   ?   ? : graugruen  */` nl
    `DWGIN_colorAssign 18 110    /* RGB :   ?   ?   ? : gruenton   */` nl
    `DWGIN_colorAssign 62 111    /* RGB :   0 251 161 : gruenton   */` nl
    `DWGIN_colorAssign 22 112    /* RGB :   ?   ?   ? : gruenton   */` nl
    `DWGIN_colorAssign 18 113    /* RGB : 100 250 155 : gruenton   */` nl
    `DWGIN_colorAssign 24 114    /* RGB :   ?   ?   ? : gruenton   */` nl
    `DWGIN_colorAssign 25 115    /* RGB :   ?   ?   ? : gruenton   */` nl
    `DWGIN_colorAssign 24 116    /* RGB :   ?   ?   ? : gruenton   */` nl
    `DWGIN_colorAssign 25 117    /* RGB :   ?   ?   ? : gruenton   */` nl
    `DWGIN_colorAssign 26 118    /* RGB :   ?   ?   ? : graugruen  */` nl
    `DWGIN_colorAssign 27 119    /* RGB :   ?   ?   ? : graugruen  */` nl
    `DWGIN_colorAssign 17 120    /* RGB :   ?   ?   ? : tuerkis    */` nl
    `DWGIN_colorAssign 63 121    /* RGB :   0 251 196 : gruenton   */` nl
    `DWGIN_colorAssign 18 122    /* RGB :   ?   ?   ? : gruenton   */` nl
    `DWGIN_colorAssign 17 123    /* RGB :  17 255 200 : gruenton   */` nl
    `DWGIN_colorAssign 18 124    /* RGB :   ?   ?   ? : gruenton   */` nl
    `DWGIN_colorAssign 17 125    /* RGB :   ?   ?   ? : gruenton   */` nl
    `DWGIN_colorAssign 24 126    /* RGB :   ?   ?   ? : gruenton   */` nl
    `DWGIN_colorAssign 25 127    /* RGB :   ?   ?   ? : gruenton   */` nl
    `DWGIN_colorAssign 26 128    /* RGB :   ?   ?   ? : graugruen  */` nl
    `DWGIN_colorAssign 27 129    /* RGB :   ?   ?   ? : graugruen  */` nl
    `DWGIN_colorAssign 16 130    /* RGB :   ?   ?   ? : blauton    */` nl
    `DWGIN_colorAssign 17 131    /* RGB :   ?   ?   ? : blauton    */` nl
    `DWGIN_colorAssign 11 132    /* RGB :   ?   ?   ? : blauton    */` nl
    `DWGIN_colorAssign 13 133    /* RGB :   ?   ?   ? : blauton    */` nl
    `DWGIN_colorAssign  9 134    /* RGB :   ?   ?   ? : ?          */` nl
    `DWGIN_colorAssign 18 135    /* RGB :   ?   ?   ? : ?          */` nl
    `DWGIN_colorAssign 18 136    /* RGB :   ?   ?   ? : ?          */` nl
    `DWGIN_colorAssign  9 137    /* RGB : 105 185 180 : ?          */` nl
    `DWGIN_colorAssign 27 138    /* RGB :   ?   ?   ? : graugruen  */` nl
    `DWGIN_colorAssign 28 139    /* RGB :  80  85  75 : graugruen  */` nl
    `DWGIN_colorAssign 32 140    /* RGB :   ?   ?   ? : blauton    */` nl
    `DWGIN_colorAssign 33 141    /* RGB :   ?   ?   ? : blauton    */` nl
    `DWGIN_colorAssign 11 142    /* RGB :   ?   ?   ? : blauton    */` nl
    `DWGIN_colorAssign 13 143    /* RGB :   ?   ?   ? : blauton    */` nl
    `DWGIN_colorAssign  1 144    /* RGB :   ?   ?   ? : blauton    */` nl
    `DWGIN_colorAssign 14 145    /* RGB :   ?   ?   ? : blauton    */` nl
    `DWGIN_colorAssign  1 146    /* RGB :   ?   ?   ? : blauton    */` nl
    `DWGIN_colorAssign 14 147    /* RGB :   ?   ?   ? : blauton    */` nl
    `DWGIN_colorAssign 28 148    /* RGB :   ?   ?   ? : graublau   */` nl
    `DWGIN_colorAssign 29 149    /* RGB :  95  75  75 : graublau   */` nl
    `DWGIN_colorAssign 32 150    /* RGB :   ?   ?   ? : blauton    */` nl
    `DWGIN_colorAssign 33 151    /* RGB :   ?   ?   ? : blauton    */` nl
    `DWGIN_colorAssign 11 152    /* RGB :   ?   ?   ? : blauton    */` nl
    `DWGIN_colorAssign 13 153    /* RGB :   ?   ?   ? : blauton    */` nl
    `DWGIN_colorAssign  1 154    /* RGB :   ?   ?   ? : blauton    */` nl
    `DWGIN_colorAssign 14 155    /* RGB :   ?   ?   ? : blauton    */` nl
    `DWGIN_colorAssign  1 156    /* RGB :   ?   ?   ? : blauton    */` nl
    `DWGIN_colorAssign 14 157    /* RGB :   ?   ?   ? : blauton    */` nl
    `DWGIN_colorAssign 28 158    /* RGB :   ?   ?   ? : graublau   */` nl
    `DWGIN_colorAssign 29 159    /* RGB :   ?   ?   ? : graublau   */` nl
    `DWGIN_colorAssign 32 160    /* RGB :   ?   ?   ? : ?        */` nl
    `DWGIN_colorAssign 33 161    /* RGB :   ?   ?   ? : ?        */` nl
    `DWGIN_colorAssign 11 162    /* RGB :   ?   ?   ? : ?        */` nl
    `DWGIN_colorAssign 13 163    /* RGB :   ?   ?   ? : ?        */` nl
    `DWGIN_colorAssign  1 164    /* RGB :   ?   ?   ? : ?        */` nl
    `DWGIN_colorAssign 14 165    /* RGB :   ?   ?   ? : ?        */` nl
    `DWGIN_colorAssign  1 166    /* RGB :   ?   ?   ? : ?        */` nl
    `DWGIN_colorAssign 14 167    /* RGB :   ?   ?   ? : ?        */` nl
    `DWGIN_colorAssign 28 168    /* RGB :   ?   ?   ? : ?        */` nl
    `DWGIN_colorAssign 29 169    /* RGB :   ?   ?   ? : ?        */` nl
    `DWGIN_colorAssign 32 170    /* RGB :   ?   ?   ? : blau     */` nl
    `DWGIN_colorAssign 33 171    /* RGB :   ?   ?   ? : ?        */` nl
    `DWGIN_colorAssign 11 172    /* RGB :   ?   ?   ? : ?        */` nl
    `DWGIN_colorAssign 13 173    /* RGB :   ?   ?   ? : ?        */` nl
    `DWGIN_colorAssign  1 174    /* RGB :   ?   ?   ? : ?        */` nl
    `DWGIN_colorAssign 14 175    /* RGB :   0   0 128 : ?        */` nl
    `DWGIN_colorAssign  1 176    /* RGB :   ?   ?   ? : ?        */` nl
    `DWGIN_colorAssign 14 177    /* RGB :   ?   ?   ? : ?        */` nl
    `DWGIN_colorAssign 28 178    /* RGB :   ?   ?   ? : ?        */` nl
    `DWGIN_colorAssign 29 179    /* RGB :   ?   ?   ? : ?        */` nl
    `DWGIN_colorAssign 32 180    /* RGB :   ?   ?   ? : ?        */` nl
    `DWGIN_colorAssign 33 181    /* RGB :   ?   ?   ? : ?        */` nl
    `DWGIN_colorAssign 13 182    /* RGB :   ?   ?   ? : ?        */` nl
    `DWGIN_colorAssign 11 183    /* RGB : 203 197 255 : ?        */` nl
    `DWGIN_colorAssign 33 184    /* RGB : 100  10 251 : ?        */` nl
    `DWGIN_colorAssign 13 185    /* RGB : 191 166 252 : ?        */` nl
    `DWGIN_colorAssign  1 186    /* RGB :   ?   ?   ? : ?        */` nl
    `DWGIN_colorAssign 14 187    /* RGB :   ?   ?   ? : ?        */` nl
    `DWGIN_colorAssign 32 188    /* RGB :   ?   ?   ? : ?        */` nl
    `DWGIN_colorAssign 33 189    /* RGB :   ?   ?   ? : ?        */` nl
    `DWGIN_colorAssign 34 190    /* RGB :   ?   ?   ? : ?        */` nl
    `DWGIN_colorAssign 35 191    /* RGB :   ?   ?   ? : ?        */` nl
    `DWGIN_colorAssign 36 192    /* RGB :   ?   ?   ? : ?        */` nl
    `DWGIN_colorAssign 37 193    /* RGB :   ?   ?   ? : ?        */` nl
    `DWGIN_colorAssign 36 194    /* RGB :   ?   ?   ? : ?        */` nl
    `DWGIN_colorAssign 37 195    /* RGB :   ?   ?   ? : ?        */` nl
    `DWGIN_colorAssign 36 196    /* RGB :   ?   ?   ? : ?        */` nl
    `DWGIN_colorAssign 37 197    /* RGB :   ?   ?   ? : ?        */` nl
    `DWGIN_colorAssign 32 198    /* RGB :   ?   ?   ? : ?        */` nl
    `DWGIN_colorAssign 33 199    /* RGB :   ?   ?   ? : ?        */` nl
    `DWGIN_colorAssign 34 200    /* RGB :   ?   ?   ? : ?        */` nl
    `DWGIN_colorAssign 35 201    /* RGB :   ?   ?   ? : ?        */` nl
    `DWGIN_colorAssign 36 202    /* RGB : 200  10 251 : ?        */` nl
    `DWGIN_colorAssign 37 203    /* RGB :   ?   ?   ? : ?        */` nl
    `DWGIN_colorAssign 35 204    /* RGB : 175   0 251 : ?        */` nl
    `DWGIN_colorAssign 37 205    /* RGB :   ?   ?   ? : ?        */` nl
    `DWGIN_colorAssign 34 206    /* RGB : 150  15 251 : ?        */` nl
    `DWGIN_colorAssign 37 207    /* RGB :   ?   ?   ? : ?        */` nl
    `DWGIN_colorAssign 32 208    /* RGB :   ?   ?   ? : ?        */` nl
    `DWGIN_colorAssign 33 209    /* RGB :   ?   ?   ? : ?        */` nl
    `DWGIN_colorAssign 37 210    /* RGB :   ?   ?   ? : ?        */` nl
    `DWGIN_colorAssign 42 211    /* RGB : 249 220 229 : ?        */` nl
    `DWGIN_colorAssign 37 212    /* RGB : 236   0 246 : ?        */` nl
    `DWGIN_colorAssign 37 213    /* RGB :   ?   ?   ? : ?        */` nl
    `DWGIN_colorAssign 36 214    /* RGB :   ?   ?   ? : ?        */` nl
    `DWGIN_colorAssign 37 215    /* RGB :   ?   ?   ? : ?        */` nl
    `DWGIN_colorAssign 36 216    /* RGB :   ?   ?   ? : ?        */` nl
    `DWGIN_colorAssign 37 217    /* RGB :   ?   ?   ? : ?        */` nl
    `DWGIN_colorAssign 32 218    /* RGB :   ?   ?   ? : ?        */` nl
    `DWGIN_colorAssign 33 219    /* RGB :   ?   ?   ? : ?        */` nl
    `DWGIN_colorAssign 37 220    /* RGB :   ?   ?   ? : ?        */` nl
    `DWGIN_colorAssign 41 221    /* RGB : 240 210 215 : ?        */` nl
    `DWGIN_colorAssign 37 222    /* RGB :   ?   ?   ? : ?        */` nl
    `DWGIN_colorAssign 37 223    /* RGB :   ?   ?   ? : ?        */` nl
    `DWGIN_colorAssign 36 224    /* RGB :   ?   ?   ? : ?        */` nl
    `DWGIN_colorAssign 37 225    /* RGB :   ?   ?   ? : ?        */` nl
    `DWGIN_colorAssign 36 226    /* RGB :   ?   ?   ? : ?        */` nl
    `DWGIN_colorAssign 37 227    /* RGB :   ?   ?   ? : ?        */` nl
    `DWGIN_colorAssign 32 228    /* RGB :   ?   ?   ? : ?        */` nl
    `DWGIN_colorAssign 33 229    /* RGB :   ?   ?   ? : ?        */` nl
    `DWGIN_colorAssign 39 230    /* RGB :   ?   ?   ? : ?        */` nl
    `DWGIN_colorAssign 40 231    /* RGB : 230 180 225 : ?        */` nl
    `DWGIN_colorAssign 41 232    /* RGB :   ?   ?   ? : ?        */` nl
    `DWGIN_colorAssign 42 233    /* RGB :   ?   ?   ? : ?        */` nl
    `DWGIN_colorAssign 41 234    /* RGB :   ?   ?   ? : ?        */` nl
    `DWGIN_colorAssign 42 235    /* RGB :   ?   ?   ? : ?        */` nl
    `DWGIN_colorAssign 41 236    /* RGB :   ?   ?   ? : ?        */` nl
    `DWGIN_colorAssign 42 237    /* RGB :   ?   ?   ? : ?        */` nl
    `DWGIN_colorAssign 32 238    /* RGB :   ?   ?   ? : ?        */` nl
    `DWGIN_colorAssign 33 239    /* RGB :   ?   ?   ? : ?        */` nl
    `DWGIN_colorAssign 49 240    /* RGB :   ?   ?   ? : ?        */` nl
    `DWGIN_colorAssign 39 241    /* RGB : 250 175 230 : ?        */` nl
    `DWGIN_colorAssign 40 242    /* RGB :   ?   ?   ? : ?        */` nl
    `DWGIN_colorAssign 49 243    /* RGB :   ?   ?   ? : ?        */` nl
    `DWGIN_colorAssign 48 244    /* RGB :   ?   ?   ? : ?        */` nl
    `DWGIN_colorAssign 49 245    /* RGB :   ?   ?   ? : ?        */` nl
    `DWGIN_colorAssign 48 246    /* RGB :   ?   ?   ? : ?        */` nl
    `DWGIN_colorAssign 49 247    /* RGB :   ?   ?   ? : ?        */` nl
    `DWGIN_colorAssign 32 248    /* RGB :   ?   ?   ? : ?        */` nl
    `DWGIN_colorAssign 33 249    /* RGB :   ?   ?   ? : ?        */` nl
    `DWGIN_colorAssign  6 250    /* RGB :   0   0   0 : schwarz  */` nl
    `DWGIN_colorAssign  7 251    /* RGB :   ?   ?   ? : grauton  */` nl
    `DWGIN_colorAssign 28 252    /* RGB :   ?   ?   ? : grauton  */` nl
    `DWGIN_colorAssign 28 253    /* RGB :   ?   ?   ? : grauton  */` nl
    `DWGIN_colorAssign 29 254    /* RGB :   ?   ?   ? : grauton  */` nl
    `DWGIN_colorAssign 15 255    /* RGB : 255 255 255 : weiss    */` nl

    close ()
    file <screen> output
  end
  return (ok)
end

function WriteConfigFile ( filename, ParamLineGroup )
    // wenn das ganze mehrmals hintereinander (in einem AQL-Lauf) angewendet wird,
    // ffnet AQL bei den Folgeaufrufen die Datei jeweils mit append ->
    // deshalb mssen wir die Datei erst mal lschen !!
    CheckedName = file_extend (filename)
    if valid (filename) then
       if ( program.host = "DOS_PC" or is_windows_host (program.host)) then
          system ( "del ", CheckedName )
      else
          system ( "rm ", CheckedName )
      end
    end    
    file filename output
    for ParamLine in ParamLineGroup do
        ParamTypeNr = GetParamTypeNr (ParamLine)
        switch ParamTypeNr
        case  0   : nl            // Empty Line
        case 88   :               // Comment
                    [GetCommentLine (ParamLine)] nl    // Write the original Comment
        otherwise :
                    // currently no specials for known types (maybe used in future)
                    [GetParam (ParamLine)] nl
        end
    end
    close ()
    file <screen> output
end

